@@ -132,3 +132,58 @@ setMethod(f = "brownian.motion.variance.dyn", signature = c(object = ".MoveTrack
 					    window.size = window.size, margin = margin)
 	return(new("dBMvarianceBurst", as(res, "dBMvarianceTmp"), object))
 	 })
+
+setMethod(f = "brownian.motion.variance.dyn", 
+          signature = c(object = "MoveStack", location.error = "numeric", window.size = "numeric", margin = "numeric"), 
+          definition = function(object, location.error, window.size, margin) {
+            
+            
+            
+            
+            
+            moveUnstacked <- split(x = object)
+            if(length(location.error)==1){
+              location.error<-split(rep(location.error,sum(n.locs(object))), 
+                                    rep(levels(trackId(object)),n.locs(object)))
+            }else{
+              if(length(location.error)!=sum(n.locs(object)))
+                stop('Location error needs to be the same length as the number of locations')
+              location.error<-split(location.error, 
+                                    rep(levels(trackId(object)),n.locs(object)))
+            }
+            # split MoveStack into individual Move objects
+            dbbmmLST <- list()
+            omitMove <- c()
+            for (i in names(moveUnstacked)) {
+              if (n.locs(moveUnstacked[[i]]) > (2*window.size - 2*margin)) {
+                dbbmmLST[[i]] <- callGeneric(moveUnstacked[[i]], location.error = location.error[[i]], margin=margin, window.size=window.size)
+              } else {
+                omitMove <- c(omitMove, i)
+              }
+              # store which Move Objects were not processed
+            }
+            if (length(omitMove) > 0) 
+              warning("Move object ", paste(omitMove, collapse = " "), " was/were omitted, because the number of coordinates is smaller than the window.size and margin you use.\n")
+            
+            objectAnimalsOmitted <- object[as.character(trackId(object)) %in% names(dbbmmLST)]
+            dBMvarianceStack <- new("dBMvarianceStack", 
+                                    objectAnimalsOmitted, 
+                                    in.windows = unlist(lapply(dbbmmLST, slot, "in.windows")), 
+                                    interest = unlist(lapply(dbbmmLST, slot, "interest")), 
+                                    means = unlist(lapply(dbbmmLST, slot, "means")), 
+                                    margin = unique(unlist(lapply(dbbmmLST, slot, "margin"))), 
+                                    window.size = unique(unlist(lapply(dbbmmLST, slot, "window.size"))))
+            
+            return(dBMvarianceStack)
+            
+            
+            
+            
+            
+            
+            
+            
+            
+            
+            })
+
